#!/bin/sh

# This helper script will handle deploying a s3 bucket
set -e

source /scripts/utils.sh
source /scripts/terraform.sh

check_access ${appsNamespace} configmaps

tfAdditionalVarsFile=${tfRoot}/additional_settings.auto.tfvars

# Sets the terraform variables that have dependencies on other sub-charts
# and could not be set from the values file at the time of installation.
echo "the glue role is ${gluecrawlerRoleArn}"
echo "glue_crawler_role_arn = \"$gluecrawlerRoleArn\" " >> ${tfAdditionalVarsFile}

echo "the glue database is ${gluecatalogDatabaseName}"
echo "aws_glue_catalog_database_name = \"$gluecatalogDatabaseName\" " >> ${tfAdditionalVarsFile}

if [ "${s3TargetEnabled}" == "false" ]  && [ "${dynamodbTargetEnabled}" == "false" ] && [ "${jdbcTargetEnabled}" == "false" ] && [ "${catalogTargetEnabled}" == "false" ] && [ "${mongodbTargetEnabled}" == "false" ]; then
echo "Must specify atleast one of the datasource target to be enabled."
echo "For glue crawler, must specify at least one of target to be enabled."
echo "Please enable one of the dynamodbTarget:enable, jdbcTarget:enable, s3Target:enable or catalogTarget:enable"
exit 1
fi

# Sets the terraform variable for s3 targetpath for glue crawler
if [ "${s3TargetEnabled}" == "true" ]; then
  if [ -z "${s3ObjectPath}" ]; then
  echo "The path to the Amazon S3 object/folder within the s3 bucket must be provided."
  exit 1
  fi
echo "s3_target_path = \"s3://${s3BucketName}${s3ObjectPath}\"" >> ${tfAdditionalVarsFile}
fi

# Sets the terraform variable for dynamodb targetPath for glue crawler
if [ "${dynamodbTargetEnabled}" == "true" ]; then
  if [ -z "${dynamodbTableName}" ]; then
  echo "TableName for dynamodb Table was not infered from the releaseName and alias provided for the dynamodbTarget."
  echo "Please check if dynamodb chart is installed. If dynamodb chart is installed, please verify the release and alias name specified for dynamodbTarget."
  exit 1
  fi
echo "dynamodb_target_path = \"${dynamodbTableName}\"" >> ${tfAdditionalVarsFile}
fi

# Sets the terraform variable for jdbcTarget for glue crawler
if [ "${jdbcTargetEnabled}" == "true" ]; then
  if [ -z "${dbReaderEndpoint}" ] || [ -z "${dbPort}" ] || [ -z "${dbName}" ] || [ -z "${dbUserCredsSecretUserName}" ] || [ -z "${dbUserCredsSecretPassName}" ]; then
  echo "Database Connection properties was not infered from the releaseName and alias provided for the jdbcTarget."
  echo "Please check if aurora chart is installed. If aurora chart is installed, please verify the release and alias name specified for jdbcTarget."
  exit 1
  fi
db_username=$(get_secret_cred ${dbUserCredsSecretUserName} ${appsNamespace} user)
db_password=$(get_secret_cred ${dbUserCredsSecretPassName} ${appsNamespace} password)
IFS='.' read -ra db_identifier_array <<< "${dbReaderEndpoint}"
echo "rds_instance_name = \"${db_identifier_array[0]}-01\"" >> ${tfAdditionalVarsFile}
echo "jdbc_url = \"jdbc:postgresql://${dbReaderEndpoint}:${dbPort}/${dbName}\"" >> ${tfAdditionalVarsFile}
echo "db_username = \"${db_username}\"" >> ${tfAdditionalVarsFile}
echo "db_password = \"${db_password}\"" >> ${tfAdditionalVarsFile}

echo "RDS Instance name is ${db_identifier_array[0]}-01"
echo "DB Reader Endpoint for aurora db is ${dbReaderEndpoint}"
echo "The Database credentials is ${db_username}  ${db_password}"
echo "JDBC Url is jdbc:postgresql://${dbReaderEndpoint}:${dbPort}/${dbName}"
fi


# Sets the terraform variable for catalog_target_database_name for glue
if [ "${catalogTargetEnabled}" == "true" ]; then
  if [ -z "${gluecatalogDatabaseName}" ]; then
  echo "Glue databaseName name was not infered from the releaseName and alias provided for the catalogTarget."
  echo "Please check if gluedatabase chart is installed. If gluedatabase chart is installed, please verify the release and alias name specified for catalogTarget."
  exit 1
  fi
echo "catalog_target_database_name = \"${gluecatalogDatabaseName}\"" >> ${tfAdditionalVarsFile}
fi

echo "iam_policy_prefix = \"${externalNamingPrefix}\"" >> ${tfAdditionalVarsFile}

terraform_init
terraform_plan
terraform_apply
terraform_output

print_header "Dump output to ConfigMap"
arnConfigMapName=${namingPrefix}-arn
terraform_get arn arnValue
terraform_get glue_crawler_policy_arn accessPolicyValue

cat >/tmp/config.yaml <<EOF
apiVersion: v1
kind: ConfigMap
metadata:
  name: ${arnConfigMapName}
data:
  ARN: ${arnValue}
  AccessPolicy: ${accessPolicyValue}
EOF

run_cmd cat "/tmp/config.yaml"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} apply -f /tmp/config.yaml
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${infraNamespace} apply -f /tmp/config.yaml

echo "Config map ${arnConfigMapName}"
/scripts/wait-until -t 30 -i 5 true kubectl --namespace ${appsNamespace} get cm ${arnConfigMapName} -o yaml

cprint "$0 done "
